import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea } from '@tarojs/components'
import Taro, { getCurrentInstance } from '@tarojs/taro'
import tool from '../../common/tool'
import TaroCanvasDrawer from '../../component/taro-plugin-canvas';
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {
    author: {},
    img_info: {},
    task_info: {},
    model_info: {},
    style: {},
    is_like: 0,
    canvasImage: '',
    qrCodeImg: '',
    // 绘图配置文件
    config: null,
    // 绘制的图片
    shareImage: null,
    // TaroCanvasDrawer 组件状态
    canvasStatus: false,
    isFill: false,//是否画海报
  }

  componentWillMount () {
    this.getDrawTaskStatus()
    this.getWxCodeImg()
  }

  getWxCodeImg () {
    api.getWxCodeImg({ code_from: 'bill' }).then(res => {
      this.dataURLtoFile(res.data)
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }
  //base64转本地路径
  dataURLtoFile (dataurl) {
    let that = this
    /// 获取到base64Data
    var base64Data = dataurl;
    /// 通过微信小程序自带方法将base64转为二进制去除特殊符号，再转回base64
    base64Data = Taro.arrayBufferToBase64(Taro.base64ToArrayBuffer(base64Data));
    /// 拼接请求头，data格式可以为image/png或者image/jpeg等，看需求
    const base64ImgUrl = "data:image/png;base64," + base64Data;

    const base64ImgData = base64ImgUrl.replace(/^data:image\/\w+;base64,/, '');
    const buffer = new ArrayBuffer(base64ImgData.length);
    const view = new Uint8Array(buffer);
    for (let i = 0; i < base64ImgData.length; i++) {
      view[i] = base64ImgData.charCodeAt(i);
    }
    const fileStream = Taro.base64ToArrayBuffer(base64ImgData);
    const filePath = Taro.env.USER_DATA_PATH + '/test.png';
    Taro.getFileSystemManager().writeFile({
      filePath: filePath,
      data: fileStream,
      encoding: 'binary',
      success: function (res) {
        console.log('writeFile success:', res, filePath);
        that.setState({
          qrCodeImg: filePath
        }, () => {
        })
      },
      fail: function (res) {
        console.log('保存失败')
      }
    })
    /// 刷新数据
    return base64ImgUrl;
  }
  // 调用绘画 => canvasStatus 置为true、同时设置config
  canvasDrawFunc () {
    let sizeList = this.state.task_info.img_size.split(":")
    console.log(sizeList, 375 * sizeList[1] / sizeList[0]);
    let rssConfig = {
      width: 345,
      height: 314 * sizeList[1] / sizeList[0] + 69 + 112,
      backgroundColor: 'rgba(255,255,255,0.1)',
      debug: false,
      pixelRatio: 3,
      blocks: [
        {
          x: 0,
          y: 0,
          width: 345,
          height: 314 * sizeList[1] / sizeList[0] + 69 + 112,
          paddingLeft: 0,
          paddingRight: 0,
          borderWidth: 0,
          // borderColor: '#ccc',
          backgroundColor: '#FFFFFF',
          borderRadius: 0,
          zIndex: 1,
        },
      ],

      images: [
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679561342726.png',
          width: 154,
          height: 21,
          x: 16,
          y: 19,
          borderRadius: 12,
          zIndex: 8,
        },
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679561346368.png',
          width: 65,
          height: 4,
          x: 261,
          y: 28,
          borderRadius: 12,
          zIndex: 8,
        },
        {
          url: this.state.img_info.img,
          width: 314,
          height: 314 * sizeList[1] / sizeList[0],
          x: 16,
          y: 69,
          borderRadius: 12,
          zIndex: 11,
        },
        {
          url: this.state.qrCodeImg,
          width: 72,
          height: 72,
          x: 258,
          y: 314 * sizeList[1] / sizeList[0] + 69 + 20,
          borderRadius: 12,
          zIndex: 12,
        },
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679562152791.png',
          width: 143,
          height: 38,
          x: 91,
          y: 314 * sizeList[1] / sizeList[0] + 69 + 34,
          borderRadius: 0,
          zIndex: 12,
        },
      ],
      // texts: [
      //   {
      //     x: 170,
      //     y: 314 * sizeList[1] / sizeList[0] + 69 + 34,
      //     text: '长按扫码',
      //     fontSize: 16,
      //     color: '#333333',
      //     opacity: 1,
      //     baseLine: 'middle',
      //     lineHeight: 22,
      //     textAlign: 'right',
      //     zIndex: 10,
      //   },
      //   {
      //     x: 91,
      //     y: 314 * sizeList[1] / sizeList[0] + 69 + 56,
      //     text: '体验AI人工智能绘画',
      //     fontSize: 16,
      //     color: '#333333',
      //     opacity: 1,
      //     baseLine: 'middle',
      //     lineHeight: 22,
      //     textAlign: 'right',
      //     zIndex: 10,
      //   },
      // ],
    }
    console.log('回执');
    this.setState({
      config: rssConfig,
    }, () => {
      this.setState({
        isFill: true
      })
    })
    Taro.showLoading({
      title: '加载中...'
    })
  }

  // 绘制成功回调函数 （必须实现）=> 接收绘制结果、重置 TaroCanvasDrawer 状态
  onCreateSuccess = (result) => {
    console.log('成功', result);
    const { tempFilePath, errMsg } = result;
    if (errMsg === 'canvasToTempFilePath:ok') {
      this.setState({
        shareImage: tempFilePath,
        // 重置 TaroCanvasDrawer 状态，方便下一次调用
        isFill: false,
        config: {}
      }, () => {
        Taro.hideLoading();
        Taro.showShareImageMenu({
          path: tempFilePath
        })
        //画图成功之后打开分享
        // Taro.downloadFile({
        //   url: this.state.shareImage,
        //   success: (res) => {
        //     Taro.showShareImageMenu({
        //       path: res.tempFilePath
        //     })
        //   }
        // })
      })
    } else {
      // 重置 TaroCanvasDrawer 状态，方便下一次调用
      this.setState({
        isFill: false,
        config: {}
      })
      Taro.showToast({ icon: 'none', title: errMsg || '出现错误' });
      console.log(errMsg);
    }
    // 预览
    // Taro.previewImage({
    //   current: tempFilePath,
    //   urls: [tempFilePath]
    // })
  }

  // 绘制失败回调函数 （必须实现）=> 接收绘制错误信息、重置 TaroCanvasDrawer 状态
  onCreateFail = (error) => {
    console.log('失败');
    Taro.hideLoading();
    // 重置 TaroCanvasDrawer 状态，方便下一次调用
    this.setState({
      isFill: false,
      config: {}
    })
    console.log(error);
  }

  // 保存图片至本地
  saveToAlbum = () => {
    const res = Taro.saveImageToPhotosAlbum({
      filePath: this.state.shareImage,
    });
    if (res.errMsg === 'saveImageToPhotosAlbum:ok') {
      Taro.showToast({
        title: '保存图片成功',
        icon: 'success',
        duration: 2000,
      });
    }
  }
  openFill () {
    this.canvasDrawFunc()
  }
  getDrawTaskStatus () {
    let routers = this.$instance.router.params
    api.getImgDetail({ img_id: routers.task_id }).then(res => {
      //定时器不要轻易改，避免造成服务器攻击
      if (res.code == 200) {
        this.setState({
          author: res.data.author,
          img_info: res.data.img_info,
          task_info: res.data.task_info,
          model_info: res.data.model_info,
          style: res.data.style,
          is_like: res.data.is_like
        })
      }
    })
  }
  download () {
    this.downImg()
  }
  // 鉴权操作 判断是否有保存到相册的权限
  // 有就直接下载 没有就弹窗提示给权限
  downImg () {
    if (process.env.TARO_ENV == 'tt') {
      this.doSaveImg()
      return
    }
    Taro.getSetting({
      success: res => {
        if (!res.authSetting['scope.writePhotosAlbum']) {
          Taro.authorize({
            scope: 'scope.writePhotosAlbum',
            success: () => {
              console.log('成功');
              this.doSaveImg()
            },
            fail: () => {
              console.log('失败');
              this.openConfirm()
            }
          })
        } else {
          this.doSaveImg()
        }
      }
    })
  }
  // 生成临时路径 保存图片到手机
  doSaveImg () {

    Taro.downloadFile({
      url: this.state.img_info.img,
      success: res => {
        Taro.saveImageToPhotosAlbum({
          filePath: res.tempFilePath,
          success: () => {
            Taro.showToast({ title: '已保存到相册', icon: 'success' })
          },
          fail: () => {
            Taro.showToast({ title: '保存失败', icon: 'none' })
          }
        })
      }
    })
  }
  // 权限弹窗
  openConfirm () {
    Taro.showModal({
      content: '检测到您没有打开小程序相册权限，是否取设置打开？',
      showCancel: true,
      success: res => {
        if (res.confirm) {
          // 打开权限
          Taro.openSetting({
            success: res => {
              this.doSaveImg()
            }
          })
        }
      }
    })
  }

  copyPrompt () {
    let routers = this.$instance.router.params
    Taro.reLaunch({
      url: `/pages/index/index?task_id=${routers.task_id}`
    })
  }
  copyPromptAI () {
    Taro.navigateTo({
      url: `/pages/faceChanging/index?img=${this.state.img_info.img}`
    })
  }

  copyNegativePrompt () {
    Taro.setClipboardData({
      data: this.state.task_info.negative_prompt,
      success: function (res) {
      }
    })
  }

  componentDidMount () { }
  //页面销毁之前调用
  componentWillUnmount () {
  }
  changeLike () {
    let img_info = this.state.img_info
    img_info.like_cnt = this.state.is_like == 0 ? this.state.img_info.like_cnt + 1 : this.state.img_info.like_cnt - 1
    this.setState({
      is_like: this.state.is_like == 0 ? 1 : 0,
      img_info: img_info
    })
    api.userLike({ img_id: this.state.img_info.id }).then(res => {

    })
  }
  previewImage () {
    Taro.previewImage({
      current: this.state.img_info.img, // 当前显示图片的http链接  
      urls: [`${this.state.img_info.img}`] // 需要预览的图片http链接列表  
    })
  }


  render () {
    return (
      <View className='mine'>
        <View className='banner-info'>
          <Image className='banner-image' mode='aspectFit' onClick={e => (this.previewImage())} src={this.state.img_info.img}></Image>
        </View>
        <View className='content'>
          <View className='draw-title'>画家信息</View>
          <View className='user-text'>
            <View className='user-left'>
              <Image className='user-img' src={this.state.author.head_img}></Image>
              <View className='user-name'>{this.state.author.user_name}</View>
            </View>
            <View className='like' onClick={e => { this.changeLike() }}>
              <Image className='like-img' src={this.state.is_like == 0 ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679296882735.png' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679296893058.png'}></Image>
              <View className='like-num'>{this.state.img_info.like_cnt}</View>
            </View>
          </View>
          <View className='draw-title'>绘画描述</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.task_info.prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              disabled
              maxlength='1000'
            />
            <View className='copy'>
              {/* <View className='copy-button' onClick={e => (this.copyPromptAI())}>
                <View>AI换脸</View>
              </View> */}
              <View className='copy-button' onClick={e => (this.copyPrompt())}>
                <View>画同款</View>
              </View>
            </View>

          </View>
          <View className='draw-content'>
            <View className='draw-info'>
              <View className='info-title'>模型</View>
              <View className='info-text'>{this.state.model_info.name} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>风格</View>
              <View className='info-text'>{this.state.style.name} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>图片尺寸</View>
              <View className='info-text'>{this.state.task_info.img_size} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>图片质量</View>
              <View className='info-text'>{this.state.task_info.img_type == 0 ? '普通' : '高清'} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>采样方式</View>
              <View className='info-text'>{this.state.task_info.sampler} </View>
            </View>
          </View>
          <View className='draw-title'>绘画不要的元素</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.task_info.negative_prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              maxlength='1000'
              disabled
            />
            {/* <View className='copy'>
              <View className='copy-button' onClick={e => (this.copyNegativePrompt())}>
                <Image className='copy-icon' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679017836200.png'></Image>
                <View>复制</View>
              </View>
            </View> */}
          </View>
        </View>
        <View className='func'>
          <View className='func-list'>
            {/* <View className='func-info'>
              <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952380367.png'></Image>
              <View>发布</View>
            </View> */}
            {/* {
              this.state.qrCodeImg.length > 0 && process.env.TARO_ENV != 'tt' &&
              <View className='func-info' onClick={e => (this.openFill())}>
                <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952396973.png'></Image>
                <View>分享</View>
              </View>
            } */}
            <View className='func-info' onClick={e => (this.download())}>
              <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952411029.png'></Image>
              <View>下载</View>
            </View>
          </View>
        </View>
        {
          this.state.isFill &&
          <TaroCanvasDrawer
            config={this.state.config} // 绘制配置
            onCreateSuccess={e => (this.onCreateSuccess(e))} // 绘制成功回调
            onCreateFail={e => (this.onCreateFail(e))} // 绘制失败回调
          />
        }
      </View>

    )
  }
}
