import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Canvas, Button } from '@tarojs/components'
import Taro, { getCurrentInstance, CanvasContext } from '@tarojs/taro'
import tool from '../../common/tool'
import TaroCanvasDrawer from '../../component/taro-plugin-canvas';
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {
    draw_status: 0,
    draw_data: {},
    draw_infos: [],
    que_cnt: 0,
    default_img: '',
    interval: null,
    current: 0,
    model_info: {},
    style_info: {},
    canvasImage: '',
    qrCodeImg: '',
    // 绘图配置文件
    config: null,
    // 绘制的图片
    shareImage: null,
    // TaroCanvasDrawer 组件状态
    canvasStatus: false,
    isFill: false,//是否画海报
    lastTime: 0,
    jumpurl: '',//广告id
    task_id: 0,//任务id
    repeat: 0,//广告次数
    dy_ad: {
    },//抖音广告id
  }

  componentDidShow () {
    this.getCoinTaskAd()
  }

  componentWillMount () {
    this.getWxCodeImg()
    this.getDrawTaskStatus()

    // this.getWxCodeImg ()
  }
  getCoinTaskAd () {
    api.getCoinTaskAd().then(res => {
      if (res.code == 200) {
        this.setState({
          jumpurl: res.data[0].jumpurl,//广告id
          task_id: res.data[0].id,//任务id
          repeat: res.data[0].repeat
        })
      }
    })
  }
  getWxCodeImg () {
    api.getWxCodeImg({ code_from: 'bill' }).then(res => {
      this.dataURLtoFile(res.data)
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }

  //base64转本地路径
  dataURLtoFile (dataurl) {
    let that = this
    /// 获取到base64Data
    var base64Data = dataurl;
    /// 通过微信小程序自带方法将base64转为二进制去除特殊符号，再转回base64
    base64Data = Taro.arrayBufferToBase64(Taro.base64ToArrayBuffer(base64Data));
    /// 拼接请求头，data格式可以为image/png或者image/jpeg等，看需求
    const base64ImgUrl = "data:image/png;base64," + base64Data;

    const base64ImgData = base64ImgUrl.replace(/^data:image\/\w+;base64,/, '');
    const buffer = new ArrayBuffer(base64ImgData.length);
    const view = new Uint8Array(buffer);
    for (let i = 0; i < base64ImgData.length; i++) {
      view[i] = base64ImgData.charCodeAt(i);
    }
    const fileStream = Taro.base64ToArrayBuffer(base64ImgData);
    const filePath = Taro.env.USER_DATA_PATH + '/test.png';
    Taro.getFileSystemManager().writeFile({
      filePath: filePath,
      data: fileStream,
      encoding: 'binary',
      success: function (res) {
        console.log('writeFile success:', res, filePath);
        that.setState({
          qrCodeImg: filePath
        }, () => {
        })
      },
      fail: function (res) {
        console.log('保存失败')
      }
    })
    /// 刷新数据
    return base64ImgUrl;
  }
  getDrawTaskStatus () {
    let routers = this.$instance.router.params
    api.getDrawTaskStatus({ task_id: routers.task_id }).then(res => {
      //定时器不要轻易改，避免造成服务器攻击
      if (res.code == 200) {
        let draw_infos = res.data.draw_infos
        if (res.data.draw_status != 2) {
          let params = {}
          params['img'] = res.data.default_img
          params['id'] = -1
          draw_infos.push(params)
        }
        console.log(draw_infos, 'draw_infos');
        if (res.data.draw_status != 2 && res.data.que_cnt > 1) {
          this.state.interval = setInterval(() => {
            clearInterval(this.state.interval)
            this.getDrawTaskStatus()
          }, 1000 * 30)
        } else if (res.data.draw_status != 2 && res.data.que_cnt <= 1) {
          clearInterval(this.state.interval)
          this.state.interval = setInterval(() => {
            this.getDrawTaskStatus()
          }, 1000 * 5)
        } else {
          clearInterval(this.state.interval)
        }
        let _current = 0
        if (res.data.draw_infos.length > 1 && routers.img_id) {
          res.data.draw_infos.forEach((item, index) => {
            if (routers.img_id == item.id) {
              _current = index
            }
          })
        }
        this.setState({
          draw_status: res.data.draw_status,
          draw_data: res.data.draw_data,
          que_cnt: res.data.que_cnt,
          draw_infos: draw_infos,
          current: _current,
          dy_ad: res.data.dy_ad,
          model_info: res.data.model_info,
          style_info: res.data.style_info
        })
      }
    })
  }
  download () {
    this.downImg()
  }
  // 鉴权操作 判断是否有保存到相册的权限
  // 有就直接下载 没有就弹窗提示给权限
  downImg () {
    Taro.getSetting({
      success: res => {
        if (!res.authSetting['scope.writePhotosAlbum']) {
          Taro.authorize({
            scope: 'scope.writePhotosAlbum',
            success: () => {
              this.doSaveImg()
            },
            fail: () => {
              this.openConfirm()
            }
          })
        } else {
          this.doSaveImg()
        }
      }
    })
  }
  // 生成临时路径 保存图片到手机
  doSaveImg () {
    Taro.downloadFile({
      url: this.state.draw_infos[0].img,
      success: res => {
        Taro.saveImageToPhotosAlbum({
          filePath: res.tempFilePath,
          success: () => {
            Taro.showToast({ title: '已保存到相册', icon: 'success' })
          },
          fail: () => {
            Taro.showToast({ title: '保存失败', icon: 'none' })
          }
        })
      }
    })
  }
  // 权限弹窗
  openConfirm () {
    Taro.showModal({
      content: '检测到您没有打开小程序相册权限，是否取设置打开？',
      showCancel: true,
      success: res => {
        if (res.confirm) {
          // 打开权限
          Taro.openSetting({
            success: res => {
              this.doSaveImg()
            }
          })
        }
      }
    })
  }

  copyPrompt () {
    Taro.setClipboardData({
      data: this.state.draw_data.prompt,
      success: function (res) {
      }
    })
  }
  copyPromptAI () {
    Taro.navigateTo({
      url: `/pages/faceChanging/index?img=${this.state.draw_infos[this.state.current].img}`
    })
  }

  copyNegativePrompt () {
    Taro.setClipboardData({
      data: this.state.draw_data.negative_prompt,
      success: function (res) {
      }
    })
  }

  componentDidMount () { }
  //页面销毁之前调用
  componentWillUnmount () {
    //避免服务器攻击
    clearInterval(this.state.interval)
  }
  previewImage (item, index) {
    Taro.previewImage({
      current: item.img, // 当前显示图片的http链接  
      urls: [`${item.img}`] // 需要预览的图片http链接列表  
    })
  }
  // 调用绘画 => canvasStatus 置为true、同时设置config
  canvasDrawFunc () {
    let sizeList = this.state.draw_data.img_size.split(":")
    console.log(sizeList, 375 * sizeList[1] / sizeList[0]);
    let rssConfig = {
      width: 345,
      height: 314 * sizeList[1] / sizeList[0] + 69 + 112,
      backgroundColor: 'rgba(255,255,255,0.1)',
      debug: false,
      pixelRatio: 3,
      blocks: [
        {
          x: 0,
          y: 0,
          width: 345,
          height: 314 * sizeList[1] / sizeList[0] + 69 + 112,
          paddingLeft: 0,
          paddingRight: 0,
          borderWidth: 0,
          // borderColor: '#ccc',
          backgroundColor: '#FFFFFF',
          borderRadius: 0,
          zIndex: 1,
        },
      ],

      images: [
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679561342726.png',
          width: 154,
          height: 21,
          x: 16,
          y: 19,
          borderRadius: 12,
          zIndex: 8,
        },
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679561346368.png',
          width: 65,
          height: 4,
          x: 261,
          y: 28,
          borderRadius: 12,
          zIndex: 8,
        },
        {
          url: this.state.draw_infos[this.state.current].img,
          width: 314,
          height: 314 * sizeList[1] / sizeList[0],
          x: 16,
          y: 69,
          borderRadius: 12,
          zIndex: 11,
        },
        {
          url: this.state.qrCodeImg,
          width: 72,
          height: 72,
          x: 258,
          y: 314 * sizeList[1] / sizeList[0] + 69 + 20,
          borderRadius: 12,
          zIndex: 12,
        },
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679562152791.png',
          width: 143,
          height: 38,
          x: 91,
          y: 314 * sizeList[1] / sizeList[0] + 69 + 34,
          borderRadius: 0,
          zIndex: 12,
        },
      ],
    }
    console.log('回执');
    this.setState({
      config: rssConfig,
    }, () => {
      this.setState({
        isFill: true
      })
    })
    Taro.showLoading({
      title: '加载中...'
    })
  }

  // 绘制成功回调函数 （必须实现）=> 接收绘制结果、重置 TaroCanvasDrawer 状态
  onCreateSuccess = (result) => {
    console.log('成功', result);
    const { tempFilePath, errMsg } = result;
    Taro.hideLoading();

    if (errMsg === 'canvasToTempFilePath:ok') {
      this.setState({
        shareImage: tempFilePath,
        // 重置 TaroCanvasDrawer 状态，方便下一次调用
        isFill: false,
        config: {}
      }, () => {
        Taro.showShareImageMenu({
          path: tempFilePath
        })
      })
      //画图成功之后打开分享
      //  Taro.downloadFile({
      //   url: tempFilePath,
      //   success: (res) => {
      //     console.log('打开分享');
      //     Taro.showShareImageMenu({
      //       path: res.tempFilePath
      //     })
      //   }
      // })
    } else {
      // 重置 TaroCanvasDrawer 状态，方便下一次调用
      this.setState({
        isFill: false,
        config: {}
      })
      Taro.showToast({ icon: 'none', title: errMsg || '出现错误' });
      console.log(errMsg);
    }
    // 预览
    // Taro.previewImage({
    //   current: tempFilePath,
    //   urls: [tempFilePath]
    // })
  }

  // 绘制失败回调函数 （必须实现）=> 接收绘制错误信息、重置 TaroCanvasDrawer 状态
  onCreateFail = (error) => {
    console.log('失败');
    Taro.hideLoading();
    // 重置 TaroCanvasDrawer 状态，方便下一次调用
    this.setState({
      isFill: false,
      config: {}
    })
    console.log(error);
  }

  // 保存图片至本地
  saveToAlbum = () => {
    const res = Taro.saveImageToPhotosAlbum({
      filePath: this.state.shareImage,
    });
    if (res.errMsg === 'saveImageToPhotosAlbum:ok') {
      Taro.showToast({
        title: '保存图片成功',
        icon: 'success',
        duration: 2000,
      });
    }
  }
  playVideo () {
    if (process.env.TARO_ENV == 'tt') {
      this.playVideoTT()
    } else {
      this.playVideoWeapp()
    }
  }
  //抖音激励广告
  playVideoTT () {
    let that = this
    Taro.showLoading({
      title: '加载中...',
    })
    const videoAd = tt.createRewardedVideoAd({ adUnitId: this.state.jumpurl });
    videoAd.show()
    videoAd.onError((err) => {
      Taro.hideLoading()
      switch (err.errCode) {
        case 1004:
          // 无合适的广告
          break;
        default:
        // 更多请参考错误码文档
      }
    });
    try {
      if (videoAd.closeHandler) {
        videoAd.offClose(videoAd.closeHandler);
        console.log("videoAd.offClose卸载成功");
      }
    } catch (e) {
      console.log("videoAd.offClose 卸载失败");
      console.error(e);
    }
    videoAd.closeHandler = function (data) {
      Taro.hideLoading()
      if (data.isEnded) {
        api.finishTask({ task_id: that.state.task_id }).then(res => {
          if (res.code == 200) {
            that.getCoinTaskAd()
            Taro.showToast({
              title: '点券+4',
              icon: 'none',
              duration: 2000
            })
          }
        })
      } else {
        Taro.showToast({
          title: '领取点券失败',
          icon: 'none',
          duration: 2000
        })
      }
    }
    // 监听视频播放完成
    videoAd.onClose(videoAd.closeHandler);
  }
  //激励广告
  playVideoWeapp () {
    // 在页面中定义激励视频广告
    let adUnitId = this.state.jumpurl
    // 在页面中定义激励视频广告
    let videoAd = null
    let that = this
    console.log(videoAd, 'videoAd');
    // 在页面onLoad回调事件中创建激励视频广告实例
    if (wx.createRewardedVideoAd) {
      videoAd = wx.createRewardedVideoAd({
        adUnitId: adUnitId
      })
      videoAd.onLoad(() => { })
      videoAd.onError((err) => { })
      try {
        if (videoAd.closeHandler) {
          videoAd.offClose(videoAd.closeHandler);
          console.log("videoAd.offClose卸载成功");
        }
      } catch (e) {
        console.log("videoAd.offClose 卸载失败");
        console.error(e);
      }
      videoAd.closeHandler = function (res) {
        // 用户点击了【关闭广告】按钮
        if (res && res.isEnded || res === undefined) {
          // 正常播放结束，可以下发游戏奖励
          api.finishTask({ task_id: that.state.task_id }).then(res => {
            if (res.code == 200) {
              that.getCoinTaskAd()
              Taro.showToast({
                title: '点券+4',
                icon: 'none',
                duration: 2000
              })
            }
          })
        } else {
          that.getCoinTaskAd()
          //提前关闭小程序
        }
      };
      videoAd.onClose(videoAd.closeHandler);

    }

    // 用户触发广告后，显示激励视频广告
    if (videoAd) {
      videoAd.show().catch(() => {
        // 失败重试
        videoAd.load()
          .then(() => videoAd.show())
          .catch(err => {
            Taro.showToast({
              title: '暂无广告',
              icon: 'none',
              duration: 2000
            })
            console.log('激励视频 广告显示失败')
          })
      })
    }

  }
  openFill () {
    this.canvasDrawFunc()
  }
  changeCurrent (e) {
    this.setState({
      current: e.detail.current
    })
    console.log(e, 'eeee');
  }
  bindload (e) {
    console.log(e, 'bindload');
  }
  binderror (e) {
    console.log(e, 'binderror');
  }
  bindclose (e) {
    console.log(e, 'bindclose');
  }


  render () {
    return (
      <View className='mine'>
        <Swiper
          className='banner'
          indicatorColor='#121D34'
          indicatorActiveColor='#0F84EC'
          circular
          current={this.state.current}
          adjustHeight='first'
          onChange={e => (this.changeCurrent(e))}
          indicatorDots
        >
          {
            this.state.draw_infos.map((item, index) => (
              <SwiperItem key={index}>
                <View className='banner-info'>
                  <Image className='banner-image' mode='aspectFit' src={item.img} onClick={e => (this.previewImage(item, index))}></Image>
                </View>
                {
                  this.state.draw_status != 2 && item.id == -1 &&
                  <View className='banner-tips'>
                    <View className='tips-left'>
                      预计等待{Math.ceil((this.state.que_cnt - 1) * 0.2 + 1)}分钟...
                    </View>
                    {
                      this.state.repeat <= 10 && this.state.jumpurl.length > 0 &&
                      < View className='tips-right' onClick={e => (tool.throttle(this.playVideo(), 2000))}>
                        点击观看广告领取积分
                      </View>
                    }
                  </View>
                }
              </SwiperItem>
            ))
          }
        </Swiper>
        {
          process.env.TARO_ENV == 'tt' && this.state.dy_ad.status && this.state.dy_ad.status == 1 &&
          <View className='ad-video'>
            <ad
              unit-id={this.state.dy_ad.ad_id}
              ad-intervals="30"
              bindload={e => (this.bindload(e))}
              binderror={e => (this.binderror(e))}
              bindclose={e => (this.bindclose(e))}
              fixed="{{fixed}}"
              type="{{type}}"
              scale="{{scale}}"
            />
          </View>
        }
        <View className='content'>
          <View className='draw-title'>绘画描述</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.draw_data.prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              maxlength='1000'
              showCount
              disabled
            />
            <View className='copy'>
              {/* <View className='copy-button-AI' onClick={e => (this.copyPromptAI())}>
                <View>AI换脸</View>
              </View> */}
              <View className='copy-button' onClick={e => (this.copyPrompt())}>
                <Image className='copy-icon' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679017836200.png'></Image>
                <View>复制</View>
              </View>
            </View>

          </View>
          <View className='draw-content'>
            <View className='draw-info'>
              <View className='info-title'>模型</View>
              <View className='info-text'>{this.state.model_info.name} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>风格</View>
              <View className='info-text'>{this.state.style_info.name} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>图片尺寸</View>
              <View className='info-text'>{this.state.draw_data.img_size} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>图片质量</View>
              <View className='info-text'>{this.state.draw_data.img_type == 0 ? '普通' : '高清'} </View>
            </View>
            <View className='draw-info'>
              <View className='info-title'>采样方式</View>
              <View className='info-text'>{this.state.draw_data.sampler} </View>
            </View>
          </View>
          <View className='draw-title'>绘画不要的元素</View>
          <View className='draw-text'>
            <Textarea
              value={this.state.draw_data.negative_prompt}
              className='draw-taxtarea'
              placeholder='| 请输入相关描述，也可以输入关键词～'
              showCount
              disabled
              maxlength='1000'
            />
            <View className='copy'>

              <View className='copy-button' onClick={e => (this.copyNegativePrompt())}>
                <Image className='copy-icon' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679017836200.png'></Image>
                <View>复制</View>
              </View>
            </View>
          </View>
        </View>
        {
          this.state.draw_status == 2 &&
          <View className='func'>
            <View className='func-list'>
              {/* {
                this.state.qrCodeImg.length > 0 && process.env.TARO_ENV != 'tt' &&
                <View className='func-info' onClick={e => (this.openFill())}>
                  <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952396973.png'></Image>
                  <View>分享</View>
                </View>
              } */}
              <View className='func-info' onClick={e => (this.download())}>
                <Image className='func-image' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1678952411029.png'></Image>
                <View>下载</View>
              </View>
            </View>
          </View>
        }
        {
          this.state.isFill &&
          <TaroCanvasDrawer
            config={this.state.config} // 绘制配置
            onCreateSuccess={e => (this.onCreateSuccess(e))} // 绘制成功回调
            onCreateFail={e => (this.onCreateFail(e))} // 绘制失败回调
          />
        }
      </View >
    )
  }
}
