import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Text, ScrollView, RichText } from '@tarojs/components'
import Taro, { getCurrentInstance } from '@tarojs/taro'
import tool from '../../common/tool'
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {
    userInfo: {},
    taskList: [],
    vip_list: [],//会员列表
    shop_list: [],//充值列表
    ext_info: {},//注意事项
    isIos: false,
    lastTime: 0,
  }
  componentDidMount () {
    this.finishTask = tool.throttle(this.finishTask.bind(this), 2000);
  }
  componentWillMount () {
    let that = this
    Taro.getSystemInfo({
      success: function (res) {
        if (res.platform != "android") {
          that.setState({
            isIos: true
          })
        }
      }
    })
    this.getCoinTaskList()
    this.getShopList()
    this.getUserInfo()

  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }

  //获取任务列表
  getCoinTaskList () {
    api.getCoinTaskList().then(res => {
      this.setState({
        taskList: res.data
      })
    })
  }
  getUserInfo () {
    api.getUserInfo().then(res => {
      if (res.code == 200) {
        this.setState({
          userInfo: res.data
        })
      }
    })
  }
  getShopList () {
    api.getShopList().then(res => {
      if (res.code == 200) {
        this.setState({
          vip_list: res.data.vip_list,
          shop_list: res.data.shop_list,
          ext_info: res.data.ext_info,
        })
      }
    })
  }
  finishTask (item, index) {
    if (item.status != 0) return
    if (item.btn_title == '观看') {
      console.log('观看');
      if (process.env.TARO_ENV == 'tt') {
        this.playVideoTT(item)
      } else {
        this.playVideo(item)
      }
      return
    }
    if (item.btn_title == '去点赞') {
      Taro.switchTab({
        url: '/pages/collection/index'
      })
      return
    }
    if (item.btn_title == '邀请') {
      Taro.navigateTo({
        url: '/pages/invite/index'
      })
      return
    }
    api.finishTask({ task_id: item.id }).then(res => {
      if (res.code == 200) {
        this.getUserInfo()
        this.getCoinTaskList()
      }
    })
  }
  //抖音激励广告
  playVideoTT (item) {
    let that = this
    Taro.showLoading({
      title: '加载中...',
    })
    const videoAd = tt.createRewardedVideoAd({ adUnitId: item.jumpurl });
    videoAd.show()
    videoAd.onError((err) => {
      Taro.hideLoading()
      switch (err.errCode) {
        case 1004:
          // 无合适的广告
          break;
        default:
        // 更多请参考错误码文档
      }
    });
    try {
      if (videoAd.closeHandler) {
        videoAd.offClose(videoAd.closeHandler);
        console.log("videoAd.offClose卸载成功");
      }
    } catch (e) {
      console.log("videoAd.offClose 卸载失败");
      console.error(e);
    }
    videoAd.closeHandler = function (data) {
      Taro.hideLoading()
      if (data.isEnded) {
        api.finishTask({ task_id: item.id }).then(res => {
          if (res.code == 200) {
            that.getUserInfo()
            that.getCoinTaskList()
            Taro.showToast({
              title: '领取点券成功',
              icon: 'none',
              duration: 2000
            })
          }
        })
      } else {
        Taro.showToast({
          title: '领取点券失败',
          icon: 'none',
          duration: 2000
        })
      }
    }
    // 监听视频播放完成
    videoAd.onClose(videoAd.closeHandler);
  }
  //微信激励广告
  playVideo (item) {
    // 在页面中定义激励视频广告
    let adUnitId = item.jumpurl
    // 在页面中定义激励视频广告
    let videoAd = null
    let that = this
    console.log(videoAd, 'videoAd');
    // 在页面onLoad回调事件中创建激励视频广告实例
    if (wx.createRewardedVideoAd) {
      videoAd = wx.createRewardedVideoAd({
        adUnitId: adUnitId
      })
      videoAd.onLoad(() => { })
      videoAd.onError((err) => { })
      try {
        if (videoAd.closeHandler) {
          videoAd.offClose(videoAd.closeHandler);
          console.log("videoAd.offClose卸载成功");
        }
      } catch (e) {
        console.log("videoAd.offClose 卸载失败");
        console.error(e);
      }
      videoAd.closeHandler = function (res) {
        // 用户点击了【关闭广告】按钮
        if (res && res.isEnded || res === undefined) {
          // 正常播放结束，可以下发游戏奖励
          api.finishTask({ task_id: item.id }).then(res => {
            if (res.code == 200) {
              that.getUserInfo()
              that.getCoinTaskList()
              Taro.showToast({
                title: '领取点券成功',
                icon: 'none',
                duration: 2000
              })
            }
          })
        } else {
          //提前关闭小程序
        }
      };
      videoAd.onClose(videoAd.closeHandler);

    }

    // 用户触发广告后，显示激励视频广告
    if (videoAd) {
      videoAd.show().catch(() => {
        // 失败重试
        videoAd.load()
          .then(() => videoAd.show())
          .catch(err => {
            Taro.showToast({
              title: '暂无广告',
              icon: 'none',
              duration: 2000
            })
            console.log('激励视频 广告显示失败')
          })
      })
    }

  }
  toShareCnt () {
    Taro.navigateTo({
      url: '/pages/shareCnt/index'
    })
  }
  //充值
  toOrder (item, index) {
    let that = this
    if (process.env.TARO_ENV === 'tt') {
      Taro.showLoading({
        title: '加载中...',
      })
      api.ttCreateOrder({ pay_info_id: item.id }).then(res => {
        if (res.code == 200) {
          Taro.hideLoading()
          tt.pay({
            orderInfo: {
              order_id: res.data.order_id,
              order_token: res.data.order_token
            },
            service: 5,
            success (item) {
              if (item.code == 0) {
                that.getUserInfo()
                setTimeout(() => {
                  that.getUserInfo()
                }, 2000);
                // 支付成功处理逻辑，只有res.code=0时，才表示支付成功
                // 但是最终状态要以商户后端结果为准
              }
            },
            fail (item) {
              // 调起收银台失败处理逻辑
            },
          });
        }
      })
    } else if (process.env.TARO_ENV === 'weapp') {
      Taro.getSystemInfo({
        success: function (res) {
          Taro.showLoading({
            title: '加载中...',
          })
          api.createOrder({ shop_id: item.id }).then(res => {
            if (res.code == 200) {
              Taro.hideLoading()
              Taro.requestPayment({
                timeStamp: res.data.timeStamp,
                nonceStr: res.data.nonceStr,
                package: res.data.package,
                signType: res.data.signType,
                paySign: res.data.paySign,
                success: function (res) {
                  // console.log(res);
                  //添加2s延迟在刷新数据
                  setTimeout(() => {
                    that.getUserInfo()
                  }, 2000);
                },
                fail: function (err) {
                  try {
                    const res = Taro.getSystemInfoSync()
                    console.log(res, 'iphone=====');
                  } catch (e) {
                  }
                }
              })
            }
          })
        }
      })
    }

  }
  //会员充值
  memberToOrder (item, index) {
    if (item.has_buy == 1) return
    let that = this
    Taro.getSystemInfo({
      success: function (res) {
        Taro.showLoading({
          title: '加载中...',
        })
        api.createOrder({ shop_id: item.id }).then(res => {
          if (res.code == 200) {
            Taro.hideLoading()
            Taro.requestPayment({
              timeStamp: res.data.timeStamp,
              nonceStr: res.data.nonceStr,
              package: res.data.package,
              signType: res.data.signType,
              paySign: res.data.paySign,
              success: function (res) {
                // console.log(res);
                //添加2s延迟在刷新数据
                setTimeout(() => {
                  this.getCoinTaskList()
                  this.getShopList()
                  this.getUserInfo()
                }, 2000);
              },
              fail: function (err) {
                try {
                  const res = Taro.getSystemInfoSync()
                  console.log(res, 'iphone=====');
                } catch (e) {
                }
              }
            })
          }
        })
      }
    })

  }
  //页面销毁之前调用
  componentWillUnmount () {
    //避免服务器攻击
  }


  render () {
    return (
      <View className='mine'>
        <View className='banner'>
          <View className='banner-left'>
            <View className='banner-title'>剩余点券：</View>
            <View className='banner-num'>{this.state.userInfo.total_coin}</View>
          </View>
          <View className='banner-right'>
            <Image className='banner-img' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679465544881.png'></Image>
          </View>
        </View>
        <View className='content'>
          {
            this.state.taskList.map((item, index) => (
              <View className='register' key={index}>
                <View className='register-left'>
                  <View className='register-title'><Image className='register-icon' src={item.img} ></Image> {item.title}</View>
                  <View className='register-tips'>{item.sub_title}</View>
                </View>
                <View className='register-right'
                  style={item.status == 0 ? '' : 'background-image: linear-gradient(-45deg, #0c1419 0%, #3b3d3e 100%);opacity: 0.5;'}
                  onClick={e => (this.finishTask(item, index))}>
                  {item.btn_title}
                </View>
              </View>
            ))
          }
          {/* {
            //分销用户
            this.state.userInfo.p_user_id == 1 &&
            <View className='register'>
              <View className='register-left'>
                <View className='register-title'><Image className='register-icon' src='http://video-img.fyshark.com/1680060033169%E5%88%86%E9%94%80.png'></Image> 分销明细</View>
              </View>
              <View className='register-right' onClick={e => (this.toShareCnt())}>查看</View>
            </View>
          }
          {
            !this.state.isIos &&
            < View >
              <View className='contact-title'>
                点券充值
              </View>
              <ScrollView
                className='recharge'
                scrollX
              >
                {
                  this.state.shop_list.map((item, index) => (
                    <View className='recharge-info' key={index}>
                      <View className='recharge-icon'><Image className='recharge-img' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679457146188.png'> </Image></View>
                      <View className='recharge-tips'>{item.sub_title}</View>
                      <View className='recharge-title'>{item.title}</View>
                      <View className='recharge-tag'>{item.tag}</View>
                      <View className='recharge-button' onClick={e => (this.toOrder(item, index))}>充值</View>
                    </View>
                  ))
                }
              </ScrollView>
              <View className='contact-title'>
                会员充值
              </View>
              <View className='member-list'>
                {
                  this.state.vip_list.map((item, index) => (
                    <View className='member-info' key={index}>
                      <View className='member-top'>
                        <RichText className='member-title' nodes={item.title}></RichText>
                        <View className='member-tag'>{item.tag}</View>
                      </View>
                      <View className='member-bottom'>
                        <View className='member-bottom-left'>
                          <RichText nodes={item.sub_title}></RichText>
                        </View>
                        <View className='member-button' style={item.has_buy == 1 ? 'background-image: linear-gradient(-45deg, #0c1419 0%, #3b3d3e 100%);opacity: 0.5;' : ''} onClick={e => (this.memberToOrder(item, index))}>{item.has_buy == 1 ? '已开通' : '开通'}</View>
                      </View>
                    </View>
                  ))
                }
              </View>
            </View>
          }
          {
            !this.state.isIos &&
            <View className='android-tips'>
              <View>注：</View>
              一经购买不可退款
            </View>
          }
          {
            this.state.isIos &&
            <View className='ios-tips'>
              ios暂不支持充值
            </View>
          } */}
        </View>
      </View >
    )
  }
}
