import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Canvas, Button } from '@tarojs/components'
import Taro, { getCurrentInstance, CanvasContext } from '@tarojs/taro'
import tool from '../../common/tool'
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {
    userInfo: {},
    cardinalInfos: [],//基数
    evenInfos: [],//偶数
    total: 0,
    page: 1,
    page_size: 20,
    selection: false,
    cardinalSelectedNum: 0,

  }

  componentDidShow () {
    this.getInit(1)
    this.getUserInfo()
  }
  getInit () {
    this.setState({
      cardinalInfos: [],//基数
      evenInfos: [],//偶数
      total: 0,
      page: 1,
      page_size: 20,
      selection: false,
      cardinalSelectedNum: 0,
      evenSelectedNum: 0,
    })
    this.getMyDraw(1)
  }
  getUserInfo () {
    api.getUserInfo().then(res => {
      if (res.code == 200) {
        this.setState({
          userInfo: res.data
        })
      }
    })
  }
  getMyDraw (page) {
    Taro.showLoading({
      title: '加载中',
    })
    let params = {
      page: page,
      page_size: this.state.page_size,
    }
    let getInit = api.getMyDraw(params)
    getInit.then(res => {
      if (res.code == 200) {
        Taro.hideLoading()
        res.data.infos.forEach((item, index) => {
          item['select'] = false
        })
        let infos = res.data.infos
        let _evenInfos = res.data.infos.filter((item, index) => {
          return index % 2 == 1
        })
        let _cardinalInfos = res.data.infos.filter((item, index) => {
          return index % 2 == 0
        })
        console.log(_cardinalInfos, '_cardinalInfos');
        let cardinalInfos = this.state.cardinalInfos.concat(_cardinalInfos)
        let evenInfos = this.state.evenInfos.concat(_evenInfos)
        this.setState({
          cardinalInfos: cardinalInfos,//基数
          evenInfos: evenInfos,//偶数
          total: res.data.total
        })
      }
    })
  }
  onReachBottom () {
    if ((this.state.cardinalInfos.length + this.state.evenInfos.length) < this.state.total) {
      this.setState({
        page: this.state.page + 1
      })
      this.getMyDraw(this.state.page + 1)
    }
    console.log('onReachBottom()');
  }
   //选中||详情页
   toDetail (item, index, type) {
    if (this.state.selection) {
      if (type == 'cardinal') {
        let _infos = this.state.cardinalInfos
        _infos[index].select = !this.state.cardinalInfos[index].select
        let infosSelect = _infos.filter(res => {
          return res.select == true
        })
        console.log(infosSelect.length, 'infosSelect');
        this.setState({
          cardinalInfos: _infos,
          cardinalSelectedNum: infosSelect.length
        })
      } else {
        let _infos = this.state.evenInfos
        _infos[index].select = !this.state.evenInfos[index].select
        let infosSelect = _infos.filter(res => {
          return res.select == true
        })
        console.log(infosSelect.length, 'infosSelect');
        this.setState({
          evenInfos: _infos,
          evenSelectedNum: infosSelect.length
        })
      }

    } else {
        Taro.navigateTo({
          url: `/pages/darwDetailIndex/index?task_id=${item.task_id}&img_id=${item.id}`
        })
      
    }
  }
  cancelDelect () {
    let _evenInfos = this.state.evenInfos
    _evenInfos.forEach((item, index) => {
      item.select = false
    })
    let _cardinalInfos = this.state.cardinalInfos
    _cardinalInfos.forEach((item, index) => {
      item.select = false
    })
    this.setState({
      cardinalInfos: _cardinalInfos,
      evenInfos: _evenInfos,
      cardinalSelectedNum: 0,
      evenSelectedNum: 0,
      selection: !this.state.selection
    })
  }
  delectiImg () {
    let that = this
    Taro.showModal({
      title: '提示',
      content: `确定删除这${this.state.cardinalSelectedNum + this.state.evenSelectedNum}张图片吗`,
      success: function (res) {
        if (res.confirm) {
          that.deleteImg()
        } else if (res.cancel) {
          console.log('用户点击取消')
        }
      }
    })
  }
  deleteImg () {
    let deleteObj = []
    this.state.cardinalInfos.forEach(res => {
      if (res.select) {
        console.log(res.id, 'res.id', res.select);
        deleteObj.push(res.id)
      }
    })
    this.state.evenInfos.forEach(res => {
      if (res.select) {
        console.log(res.id, 'res.id', res.select);
        deleteObj.push(res.id)
      }
    })
    console.log(deleteObj.join(','), 'deleteObj');
    api.userDelImg({ img_ids: deleteObj.join(',') }).then(res => {
      if (res.code == 200) {
        Taro.showToast({
          title: `删除成功`,
          icon: 'none',
        });
        this.getInit(1)
        this.getUserInfo()
      }
    })
  }
  //批量选择
  changeSelection () {
    if (this.state.selection) {
      let _evenInfos = this.state.evenInfos
      _evenInfos.forEach((item, index) => {
        item.select = false
      })
      let _cardinalInfos = this.state.cardinalInfos
      _cardinalInfos.forEach((item, index) => {
        item.select = false
      })
      this.setState({
        cardinalInfos: _cardinalInfos,
        evenInfos: _evenInfos,
        cardinalSelectedNum: 0,
        evenSelectedNum: 0,
        selection: !this.state.selection
      })
    } else {
      this.setState({
        selection: !this.state.selection
      })
    }
  }

  getEarnPoints () {
    Taro.navigateTo({
      url: `/pages/earnPoints/index`
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }

  render () {
    return (
      <View className='mine'>
        <View className='work-list'>
          <View className='work-num'>作品数量：{this.state.total}/{this.state.userInfo.stock_cnt}</View>
          <View className='work-list-info' >
              <View className='selection' onClick={e => (this.changeSelection())}>{!this.state.selection ? '批量选择' : '取消'}</View>
            
            <View className='selection-left'>
              {
                this.state.cardinalInfos.map((item, index) => (
                  <View className='work-info' key={index} onClick={e => (this.toDetail(item, index, 'cardinal'))}>
                    {
                      this.state.selection &&
                      <Image className='select' src={item.select ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033915899.jpg' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033897198.jpg'}></Image>
                    }
                    <Image className='work-img' lazyLoad mode='widthFix' src={item.img ? item.img : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679305142417.png'}></Image>
                    <View className='work-name'>{tool.ellipsis(item.img_info, 8)}</View>
                  </View>
                ))
              }
            </View>
            <View className='selection-right'>
              {
                this.state.evenInfos.map((item, index) => (
                  <View className='work-info' key={index} onClick={e => (this.toDetail(item, index, 'even'))}>
                    {
                      this.state.selection &&
                      <Image className='select' src={item.select ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033915899.jpg' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033897198.jpg'}></Image>
                    }
                    <Image className='work-img' lazyLoad mode='widthFix' src={item.img}></Image>
                    <View className='work-name'>{tool.ellipsis(item.img_info, 8)}</View>
                  </View>
                ))
              }
            </View>
          </View>
        </View>
        {
          this.state.selection &&
          <View className='select-content'>
            <View className='cancel' onClick={e => (this.cancelDelect())}>取消</View>
            <View >当前已选中{this.state.cardinalSelectedNum + this.state.evenSelectedNum}张</View>
            <View className='delect' onClick={e => (this.delectiImg())}>
              <Image className='delect-icon' src='https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679037709270.png'></Image>
              <View className='delect-text'>删除</View>
            </View>
          </View>
        }
      </View>
    )
  }
}
