import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Canvas, Button } from '@tarojs/components'
import Taro, { getCurrentInstance, CanvasContext } from '@tarojs/taro'
import tool from '../../common/tool'
import TaroCanvasDrawer from '../../component/taro-plugin-canvas';
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  $instance = getCurrentInstance()
  state = {

    canvasImage: '',
    qrCodeImg: '',
    // 绘图配置文件
    config: {},
    // 绘制的图片
    shareImage: '',
    // TaroCanvasDrawer 组件状态
    canvasStatus: false,
    isFill: false,//是否画海报
  }

  componentDidMount () {

  }

  componentWillMount () {
    this.getWxCodeImg()
  }
  getWxCodeImg () {
    Taro.showLoading({
      title: '加载中...'
    })
    api.getWxCodeImg({ code_from: 'bill' }).then(res => {
      this.dataURLtoFile(res.data)
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }

  //base64转本地路径
  dataURLtoFile (dataurl) {
    let that = this
    /// 获取到base64Data
    var base64Data = dataurl;
    /// 通过微信小程序自带方法将base64转为二进制去除特殊符号，再转回base64
    base64Data = Taro.arrayBufferToBase64(Taro.base64ToArrayBuffer(base64Data));
    /// 拼接请求头，data格式可以为image/png或者image/jpeg等，看需求
    const base64ImgUrl = "data:image/png;base64," + base64Data;

    const base64ImgData = base64ImgUrl.replace(/^data:image\/\w+;base64,/, '');
    const buffer = new ArrayBuffer(base64ImgData.length);
    const view = new Uint8Array(buffer);
    for (let i = 0; i < base64ImgData.length; i++) {
      view[i] = base64ImgData.charCodeAt(i);
    }
    const fileStream = Taro.base64ToArrayBuffer(base64ImgData);
    const filePath = Taro.env.USER_DATA_PATH + '/test.png';
    Taro.getFileSystemManager().writeFile({
      filePath: filePath,
      data: fileStream,
      encoding: 'binary',
      success: function (res) {
        console.log('writeFile success:', res, filePath);
        that.setState({
          qrCodeImg: filePath
        }, () => {
          that.canvasDrawFunc()
        })
      },
      fail: function (res) {
        console.log('保存失败')
      }
    })
    /// 刷新数据
    return base64ImgUrl;
  }
  download () {
    this.downImg()
  }
  // 鉴权操作 判断是否有保存到相册的权限
  // 有就直接下载 没有就弹窗提示给权限
  downImg () {
    Taro.getSetting({
      success: res => {
        if (!res.authSetting['scope.writePhotosAlbum']) {
          Taro.authorize({
            scope: 'scope.writePhotosAlbum',
            success: () => {
              this.doSaveImg()
            },
            fail: () => {
              this.openConfirm()
            }
          })
        } else {
          this.doSaveImg()
        }
      }
    })
  }
  // 生成临时路径 保存图片到手机
  doSaveImg () {
    Taro.downloadFile({
      url: this.state.draw_infos[0].img,
      success: res => {
        Taro.saveImageToPhotosAlbum({
          filePath: res.tempFilePath,
          success: () => {
            Taro.showToast({ title: '已保存到相册', icon: 'success' })
          },
          fail: () => {
            Taro.showToast({ title: '保存失败', icon: 'none' })
          }
        })
      }
    })
  }
  // 权限弹窗
  openConfirm () {
    Taro.showModal({
      content: '检测到您没有打开小程序相册权限，是否取设置打开？',
      showCancel: true,
      success: res => {
        if (res.confirm) {
          // 打开权限
          Taro.openSetting({
            success: res => {
              this.doSaveImg()
            }
          })
        }
      }
    })
  }

  copyPrompt () {
    Taro.setClipboardData({
      data: this.state.draw_data.prompt,
      success: function (res) {
      }
    })
  }

  copyNegativePrompt () {
    Taro.setClipboardData({
      data: this.state.draw_data.negative_prompt,
      success: function (res) {
      }
    })
  }

  componentDidMount () { }
  //页面销毁之前调用
  previewImage (item, index) {
    Taro.previewImage({
      current: item.img, // 当前显示图片的http链接  
      urls: [`${item.img}`] // 需要预览的图片http链接列表  
    })
  }
  // 调用绘画 => canvasStatus 置为true、同时设置config
  canvasDrawFunc () {
    let rssConfig = {
      width: 352,
      height: 526,
      backgroundColor: 'rgba(255,255,255,0)',
      debug: false,
      pixelRatio: 3,
      blocks: [
      ],
      images: [
        {
          url: 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679730160667.png',
          width: 352,
          height: 526,
          x: 0,
          y: 0,
          borderRadius: 12,
          zIndex: 8,
        },
        {
          url: this.state.qrCodeImg,
          width: 156,
          height: 156,
          x: 97,
          y: 131,
          borderRadius: 12,
          zIndex: 12,
        },
      ],
    }
    console.log('回执');
    this.setState({
      config: rssConfig,
    }, () => {
      this.setState({
        isFill: true
      })
    })

  }

  // 绘制成功回调函数 （必须实现）=> 接收绘制结果、重置 TaroCanvasDrawer 状态
  onCreateSuccess = (result) => {
    console.log('成功', result);
    const { tempFilePath, errMsg } = result;
    Taro.hideLoading();

    if (errMsg === 'canvasToTempFilePath:ok') {
      this.setState({
        shareImage: tempFilePath,
        // 重置 TaroCanvasDrawer 状态，方便下一次调用
        isFill: false,
        config: {}
      }, () => {

      })
      //画图成功之后打开分享
      //  Taro.downloadFile({
      //   url: tempFilePath,
      //   success: (res) => {
      //     console.log('打开分享');
      //     Taro.showShareImageMenu({
      //       path: res.tempFilePath
      //     })
      //   }
      // })
    } else {
      // 重置 TaroCanvasDrawer 状态，方便下一次调用
      this.setState({
        isFill: false,
        config: {}
      })
      Taro.showToast({ icon: 'none', title: errMsg || '出现错误' });
      console.log(errMsg);
    }
    // 预览
    // Taro.previewImage({
    //   current: tempFilePath,
    //   urls: [tempFilePath]
    // })
  }

  // 绘制失败回调函数 （必须实现）=> 接收绘制错误信息、重置 TaroCanvasDrawer 状态
  onCreateFail = (error) => {
    console.log('失败');
    Taro.hideLoading();
    // 重置 TaroCanvasDrawer 状态，方便下一次调用
    this.setState({
      isFill: false,
      config: {}
    })
    console.log(error);
  }

  // 保存图片至本地
  saveToAlbum = () => {
    const res = Taro.saveImageToPhotosAlbum({
      filePath: this.state.shareImage,
      success: () => {
        Taro.showToast({ title: '已保存到相册', icon: 'success' })
      },
      fail: () => {
        Taro.showToast({ title: '保存失败', icon: 'none' })
      }
    });
  }
  //分享
  shareImage () {
    Taro.showShareImageMenu({
      path: this.state.shareImage
    })
  }
  openFill () {
    this.canvasDrawFunc()
  }


  render () {
    return (
      <View className='mine'>
        {
          this.state.shareImage.length > 0 &&
          <View className='content'>
            <Image className='invite-image' src={this.state.shareImage}></Image>

            <View className='console'>
              <View className='inte-button' onClick={e => (this.saveToAlbum())}>保存</View>
              {/* <View className='inte-button' onClick={e => (this.shareImage())}>分享</View> */}
            </View>
          </View>
        }
        {
          this.state.isFill &&
          <View>
            <TaroCanvasDrawer
              config={this.state.config} // 绘制配置
              onCreateSuccess={e => (this.onCreateSuccess(e))} // 绘制成功回调
              onCreateFail={e => (this.onCreateFail(e))} // 绘制失败回调
            />
          </View>
        }
      </View>
    )
  }
}
