import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Canvas, Button } from '@tarojs/components'
import Taro, { getCurrentInstance, CanvasContext } from '@tarojs/taro'
import tool from '../../common/tool'
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  state = {
    userInfo: {},
    type: 0,
    cardinalInfos: [],//基数
    evenInfos: [],//偶数
    total: 0,
    page: 1,
    page_size: 20,
    selection: false,
    cardinalSelectedNum: 0,

  }

  componentDidShow () {
    this.getInit(1)
  }
  getInit () {
    this.setState({
      cardinalInfos: [],//基数
      evenInfos: [],//偶数
      total: 0,
      page: 1,
      page_size: 20,
      selection: false,
      cardinalSelectedNum: 0,
      evenSelectedNum: 0,
    })
    this.getMyDraw(1)
  }
  getMyDraw (page) {
    Taro.showLoading({
      title: '加载中',
    })
    let params = {
      page: page,
      page_size: this.state.page_size,
    }
   let getInit = api.getLikeList(params)
    getInit.then(res => {
      if (res.code == 200) {
        Taro.hideLoading()
        res.data.infos.forEach((item, index) => {
          item['select'] = false
        })
        let infos = res.data.infos
        let _evenInfos = res.data.infos.filter((item, index) => {
          return index % 2 == 1
        })
        let _cardinalInfos = res.data.infos.filter((item, index) => {
          return index % 2 == 0
        })
        console.log(_cardinalInfos, '_cardinalInfos');
        let cardinalInfos = this.state.cardinalInfos.concat(_cardinalInfos)
        let evenInfos = this.state.evenInfos.concat(_evenInfos)
        this.setState({
          cardinalInfos: cardinalInfos,//基数
          evenInfos: evenInfos,//偶数
          total: res.data.total
        })
      }
    })
  }
  onReachBottom () {
    if ((this.state.cardinalInfos.length + this.state.evenInfos.length) < this.state.total) {
      this.setState({
        page: this.state.page + 1
      })
      this.getMyDraw(this.state.page + 1)
    }
    console.log('onReachBottom()');
  }
  //选中||详情页
  toDetail (item, index, type) {
    Taro.navigateTo({
      url: `/pages/communityDetail/index?task_id=${item.id}`
    })
  }
  delectiImg () {
    let that = this
    Taro.showModal({
      title: '提示',
      content: `确定删除这${this.state.cardinalSelectedNum + this.state.evenSelectedNum}张图片吗`,
      success: function (res) {
        if (res.confirm) {
          that.deleteImg()
        } else if (res.cancel) {
          console.log('用户点击取消')
        }
      }
    })
  }
  deleteImg () {
    let deleteObj = []
    this.state.cardinalInfos.forEach(res => {
      if (res.select) {
        console.log(res.id, 'res.id', res.select);
        deleteObj.push(res.id)
      }
    })
    this.state.evenInfos.forEach(res => {
      if (res.select) {
        console.log(res.id, 'res.id', res.select);
        deleteObj.push(res.id)
      }
    })
    console.log(deleteObj.join(','), 'deleteObj');
    api.userDelImg({ img_ids: deleteObj.join(',') }).then(res => {
      if (res.code == 200) {
        Taro.showToast({
          title: `删除成功`,
          icon: 'none',
        });
        this.getInit(1)
        this.getUserInfo()
      }
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }
  render () {
    return (
      <View className='mine'>
        <View className='work-list'>
          <View className='work-list-info' >
            <View className='selection-left'>
              {
                this.state.cardinalInfos.map((item, index) => (
                  <View className='work-info' key={index} onClick={e => (this.toDetail(item, index, 'cardinal'))}>
                    {
                      this.state.selection &&
                      <Image className='select' src={item.select ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033915899.jpg' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033897198.jpg'}></Image>
                    }
                    <Image className='work-img' lazyLoad mode='widthFix' src={item.img ? item.img : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679305142417.png'}></Image>
                    <View className='work-name'>{tool.ellipsis(item.img_info, 8)}</View>
                  </View>
                ))
              }
            </View>
            <View className='selection-right'>
              {
                this.state.evenInfos.map((item, index) => (
                  <View className='work-info' key={index} onClick={e => (this.toDetail(item, index, 'even'))}>
                    {
                      this.state.selection &&
                      <Image className='select' src={item.select ? 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033915899.jpg' : 'https://we-spa.oss-cn-shenzhen.aliyuncs.com/total_picture/1679033897198.jpg'}></Image>
                    }
                    <Image className='work-img' lazyLoad mode='widthFix' src={item.img}></Image>
                    <View className='work-name'>{tool.ellipsis(item.img_info, 8)}</View>
                  </View>
                ))
              }
            </View>
          </View>
        </View>
      </View>
    )
  }
}
