import { Component } from 'react'
import { View, Swiper, SwiperItem, Image, Textarea, Canvas, Button } from '@tarojs/components'
import Taro, { getCurrentInstance, CanvasContext } from '@tarojs/taro'
import tool from '../../common/tool'
import * as api from '../../service/index'
import './index.less'

export default class Task extends Component {
  state = {
    list: [
    ],
    total: false,
    page: 1,
    page_size: 20,
  }

  componentDidMount () {
    this.init()
  }
  init () {
    this.setState({
      list: [],
      total: false,
      page: 1,
      page_size: 20,
    }, () => {
      this.getInformationList()
    })
  }
  getInformationList () {
    let params = {
      page: this.state.page,
      page_size: this.state.page_size,
    }
    api.getInformationList(params).then(res => {
      if (res.code == 200) {
        let total = true
        if (res.data.length < this.state.page_size) {
          total = false
        }
        let walletList = this.state.list.concat(res.data)
        this.setState({
          list: walletList,
          total: total,
          share: res.data.share
        })
      }
    })
  }
  toRealDetail (item) {
    Taro.navigateTo({
      url: `/pages/realDetail/index?task_id=${item.id}`
    })
  }
  onReachBottom () {
    if (!this.state.total) return
    this.setState({
      page: this.state.page + 1
    }, () => {
      this.getUserShareCnt()
    })
  }
  onShareAppMessage = (res) => {
    let path = `/pages/index/index?c=${Taro.getStorageSync('user_id')}&s=rightTap`
    if (process.env.TARO_ENV == 'tt') {
      path = `/pages/index/index?c=channel_name&s=douyinguazai`
    }
    let shareData = {
      title: tool.shareTitle,
      path: path,
      imageUrl: tool.shareImg
    }
    return shareData;
  }

  render () {
    return (
      <View className='mine'>
        {
          this.state.list.map((item, index) => (
            <View className='real-info' key={index} onClick={e => (this.toRealDetail(item))}>
              <Image className='real-img' src={item.img}></Image>
              <View className='real-content'>
                <View className='real-title'>{item.title}</View>
                <View className='real-text'>{tool.ellipsis(item.sub_title, 27)}</View>
                <View className='real-date'>{item.time}</View>
              </View>
            </View>
          ))
        }
      </View>
    )
  }
}
